//+------------------------------------------------------------------+
//|                                                  MarketZones.mq4 |
//|                                         Copyright  2011, Geafer |
//|                                                                  |
//+------------------------------------------------------------------+
#property copyright "Copyright  2011, Geafer"
#property link      ""

#property indicator_chart_window

//---- vstupn parametry
extern bool      London_Show = true;
extern color     London_Color = Blue;
extern string    London_Text = "London";

extern bool      NewYork_Show = true;
extern color     NewYork_Color = Red;
extern string    NewYork_Text = "New York";

extern bool      Sydney_Show = true;
extern color     Sydney_Color = Green;
extern string    Sydney_Text = "Sydney";

extern bool      Tokio_Show = true;
extern color     Tokio_Color = Yellow;
extern string    Tokio_Text = "Tokio";

//---- zkladn nzvy objekt
string London_BaseName = "MZLondon";
string NewYork_BaseName = "MZNewYork";
string Sydney_BaseName = "MZSydney";
string Tokio_BaseName = "MZTokio";

// inicializace
int init()
{  
   // pokud se m zobrazit London, vytvome MZ
   if(London_Show)
   {
      createMZ(London_BaseName, London_Color, London_Text);
   }

   // pokud se m zobrazit New York, vytvome MZ   
   if(NewYork_Show)
   {
      createMZ(NewYork_BaseName, NewYork_Color, NewYork_Text);
   }
   
   // pokud se m zobrazit Sydney, vytvome MZ   
   if(Sydney_Show)
   {
      createMZ(Sydney_BaseName, Sydney_Color, Sydney_Text);
   }
   
   // pokud se m zobrazit Tokio, vytvome MZ   
   if(Tokio_Show)
   {
      createMZ(Tokio_BaseName, Tokio_Color, Tokio_Text);
   }
   
   return(0);
}

// deinicializace
int deinit()
{
   // smazn MZ pro London
   deleteMZ(London_BaseName);
   // smazn MZ pro New York
   deleteMZ(NewYork_BaseName); 
   // smazn MZ pro Sydney
   deleteMZ(Sydney_BaseName);
   // smazn MZ pro Tokio
   deleteMZ(Tokio_BaseName);  
   
   return(0);
}

// bh indiktoru
int start()
{
   string currentDate = TimeToStr(TimeCurrent(), TIME_DATE);
     
   // pokud se m vykreslit London, pekreslme MZ   
   if(London_Show)
   {
      redrawMZ(London_BaseName, currentDate, "09:00", "17:59");
   }      
   
   // pokud se m vykreslit New York, pekreslme MZ
   if(NewYork_Show)
   {
      redrawMZ(NewYork_BaseName, currentDate, "14:00", "22:59");
   }

   // pokud se m vykreslit Sydney, pekreslme MZ   
   if(Sydney_Show)
   {
      redrawMZ(Sydney_BaseName, currentDate, "23:00", "07:59");
   } 
   
   // pokud se m vykreslit Tokio, pekreslme MZ   
   if(Tokio_Show)
   {
      redrawMZ(Tokio_BaseName, currentDate, "01:00", "09:59");
   }       

   return(0);
}

// vytvo vertikln linii
// name = nzev linie
// c = barva linie
void createVLine(string name, color c)
{
   // kontrola, zda objekt neexistuje
   if(ObjectFind(name) < 0)
   {
      // pokud se podailo objekt vytvoit, meme nastavit vlastnosti
      if(ObjectCreate(name, OBJ_VLINE, 0, 0, 0))
      {
         ObjectSet(name, OBJPROP_COLOR, c);
         ObjectSet(name, OBJPROP_STYLE, STYLE_DOT);
         ObjectSet(name, OBJPROP_BACK, true);
         ObjectSet(name, OBJPROP_TIMEFRAMES, OBJ_PERIOD_M1|OBJ_PERIOD_M5|OBJ_PERIOD_M15|OBJ_PERIOD_M30|OBJ_PERIOD_H1);
      }
   }
}

// pekresl vertikln linii
// name = nzev linie
// dt = datum umstn linie
void redrawVLine(string name, datetime dt)
{
   if(ObjectFind(name) > -1)
   {
      ObjectSet(name, OBJPROP_TIME1, dt);
   }
}

// vytvo textov objekt
// name = nzev textovho objektu
// text = zobrazovan text
// c = barva textu
void createText(string name, string text, color c)
{
   // kontrola, zda objekt neexistuje
   if(ObjectFind(name) < 0)
   {
      // pokud se podailo objekt vytvoit, meme nastavit vlastnosti
      if(ObjectCreate(name, OBJ_TEXT, 0, 0, 0))
      {
         ObjectSetText(name, text, 8, "Arial", c);
         ObjectSet(name, OBJPROP_ANGLE, 90);
         ObjectSet(name, OBJPROP_TIMEFRAMES, OBJ_PERIOD_M1|OBJ_PERIOD_M5|OBJ_PERIOD_M15|OBJ_PERIOD_M30|OBJ_PERIOD_H1);
      }
   }
}

// pekresl textov objekt
// name = nzev textovho objektu
// dt = datum umstn textovho objektu
void redrawText(string name, datetime dt)
{
   if(ObjectFind(name) > -1)
   {
      ObjectSet(name, OBJPROP_TIME1, dt);
      ObjectSet(name, OBJPROP_PRICE1, (WindowPriceMax() - WindowPriceMin()) / 2 + WindowPriceMin());
   }
}

// vytvo MarketZone (MZ) linie
// baseName = zkladn nzev MZ
// c = barva MZ
// text = popisek MZ
void createMZ(string baseName, color c, string text)
{
   // nzev linie zobrazujc oteven marketu
   string nameOpen = baseName + "Open";
   // nzev linie zobrazujc zaven marketu
   string nameClose = baseName + "Close";
   // nzev textu zobrazujc popis marketu
   string nameText = baseName + "Text";
   
   createVLine(nameOpen, c);
   createVLine(nameClose, c);
   createText(nameText, text, c);
}

// odstran MarketZone linie
// baseName = zkladn nzev MZ
void deleteMZ(string baseName)
{
   ObjectDelete(baseName + "Open");
   ObjectDelete(baseName + "Close");
   ObjectDelete(baseName + "Text");
}

// pekresl MarketZone linii
// baseName = zkladn nzev MZ
// currentDate = etzec aktulnho datumu (bez asu)
// timeOpen = etzec asu oteven marketu
// timeClose = etzec asu zaven marketu
void redrawMZ(string baseName, string currentDate, string timeOpen, string timeClose)
{
   // nzev linie zobrazujc oteven marketu
   string nameOpen = baseName + "Open";
   // nzev linie zobrazujc zaven marketu
   string nameClose = baseName + "Close";
   // nzev textu zobrazujc popis marketu
   string nameText = baseName + "Text";
   
   // vytvoen datumu pro otevrac a zavrac dobu
   datetime dtOpen = StrToTime(currentDate + " " + timeOpen);
   datetime dtClose = StrToTime(currentDate + " " + timeClose);
   
   redrawVLine(nameOpen, dtOpen);
   redrawVLine(nameClose, dtClose);
   redrawText(nameText, dtOpen);
   
   WindowRedraw();
}